*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=C:\HOW\DelGobbo\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*  Include recent version of the ExcelXP ODS tagset;

%include "&SAMPDIR.ExcelXP.sas";

*  Create a custom style based on the stock "sansPrinter" style;

proc template;
  define style styles.XLSansPrinter;
    parent=styles.sansPrinter;

    /*  Controls the appearance of all column headings  */

    style header from header /
      background=white
      font_size=10pt
      just=center;

    /*  Used to control the appearance of the Rating "data" cells  */

    style data_center from data /
      just=center;

    /*  Used to convert SAS date values to Excel date values  */

    style data_mdy from data /
      just=right
      tagattr='format:m/d/yyyy type:DateTime';

    /*  Used to add a formula and format to the ReviewTime "data" cells  */

    style data_monthcalc from data_center /
      tagattr='formula:=ROUND(((RC[-1]-RC[-2])/365.24)*12,1) format:0.0';

  end;
run; quit;

ods listing close;
ods tagsets.ExcelXP path="&SAMPDIR" file='DrugApprovals.xml' style=XLsansPrinter;

  *  Set some tagset options;

  ods tagsets.ExcelXP options(embedded_titles='yes'
                              suppress_bylines='yes'
                              sheet_interval='bygroup' sheet_label=' ' 
                              width_points='1' width_fudge='1'
                              absolute_column_width='143,110,36,58.5,58.5,57.75'
                              autofit_height='yes');

  title1 'U.S. New Drug (NME) Approvals of #BYVAL(Year):';
  title2 'NDA Review Times by Drug';
  footnote;

  *  Create a separate worksheet for each year;

  proc print data=sample.DrugApprovals noobs label split='*';
    by year;
    pageby year;
    var Drug Firm;
    var Rating / style(Data)=data_center;
    var SubmissionDate ApprovalDate / style(Data)=data_mdy;
    var ReviewTime / style(Data)=data_monthcalc;
    format SubmissionDate ApprovalDate yymmdd10.;
  run; quit;

ods tagsets.ExcelXP close;